% Lightspeed Toolbox.  
% Efficient operations for matlab programming.
% Version 1.3.2  12-Sep-03      BSD license
% By Thomas P. Minka (my surname at stat.cmu.edu)
%
% Matrix algebra
%   repmat           - Fast replacement for matlab's repmat.
%   row_sum          - Sum for each row.  Faster than 'sum'.
%   scale_rows       - Scale each row of a matrix.
%   scale_cols       - Scale each column of a matrix.
%   solve_triu       - Left division by upper triangular matrix.
%   solve_tril       - Left division by lower triangular matrix.
%   sqdist           - Squared Euclidean and Mahalanobis distance.
%   isposdef         - Check for positive-definiteness.
%   logdet           - log(determinant) for positive definite matrix.
%
% Statistics
%   normpdf          - Multivariate normal density.
%   normpdfln        - Log of multivariate normal density.
%   normcdf          - Normal cumulative distribution.
%   normcdfln        - Log of normal cumulative distribution.
%   sample           - Sample from categorical distribution.
%   sample_hist      - Sample from multinomial distribution.
%   randbinom        - Sample from binomial distribution.
%   randnorm         - Sample from multivariate normal.
%   randgamma        - Sample from Gamma distribution.
%   randbeta         - Sample from Beta distribution.
%   int_hist         - Histogram of integer values.
%   hhist            - Locally-adaptive unbiased density estimate.
%
% Utility
%   logsumexp        - Sum in the log domain.
%   ndgridmat        - Matrix of grid points.
%   gammaln          - Fast replacement for matlab's gammaln.
%   digamma          - Derivative of gammaln.
%   trigamma         - Derivative of digamma.
%
% Readability
%   rows             - Number of rows.
%   cols             - Number of columns.
%   col_sum          - Sum for each column.
%
% Graphics
%   axis_pct         - Set reasonable axis limits.
%   draw_circle      - Add circles to current plot.
%   draw_ellipse     - Add ellipses to current plot.
%   draw_ellipse_axes - Add ellipse major and minor axes to current plot.
%   draw_line_clip   - Add a line with given parameters to current plot.
%   mobile_text      - Add draggable text to current plot.
%   mobile_points    - Add draggable points to current plot.
%   move_obj         - Make a graphics object draggable.
%
% Flop counting
%   flops            - Read/write flop counter.
%   flops_chol,
%   flops_solve, ... - Flop count for various operations.
%
% Stand alone programs
%   matfile          - Read/write MAT files.
%   test_flops       - Compare time versus flops for various math operations.
%
% Demos
%   test_repmat,
%   test_solve_tri, ...
