function h = sample_hist(p, n)
% SAMPLE_HIST     Sample from a multinomial distribution.
% Returns a column vector of counts, same length as p, whose sum is n.

% The advantage of this alg is that the running time grows slowly with n.
% It is the same alg used by BUGS.
% If n is very small then it is faster to just take n samples from p.

if nargin < 2
  n = 1;
end

h = zeros(length(p), 1);
z = 1;
% loop bins
for i = 1:(length(p)-1)
  % the count in bin i is a binomial distribution
  h(i) = randbinom(p(i)/z, n);
  n = n - h(i);
  z = z - p(i);
  if z == 0
    break
  end
end
h(length(p)) = n;
